==> wp2-be-event-bs-server-1.1.0-sources.jar: com/finconsgroup/itserr/marketplace/event/bs/configuration/properties/EventBsConfigurationProperties.java <==
package com.finconsgroup.itserr.marketplace.event.bs.configuration.properties;

import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.validation.annotation.Validated;

/**
 * Configuration properties for the event bs service.
 * <p>
 * These properties are mapped from the {@code event.bs} prefix in the application configuration.
 */
@Data
@Validated
@ConfigurationProperties(prefix = "event.bs")
public class EventBsConfigurationProperties {

    /**
     * Base URL used by Swagger/OpenAPI documentation.
     * Example: {@code http://localhost:8080}
     */
    @NotBlank
    private String swaggerApiServerUrl;

    /**
     * imagesFolderName The folder name in the user's workspace to store image for event.
     */
    @NotBlank
    private String imagesFolderName;

    /**
     * Messaging-related configuration properties.
     */
    @NotNull
    @Valid
    private Messaging messaging;

    /**
     * Diagnostics-related configuration properties.
     */
    @NotNull
    @Valid
    private Diagnostics diagnostics;

    /**
     * Configuration for messaging
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Messaging {

        /**
         * Name of the configured producer
         */
        @NotBlank
        private String producerName;

        /**
         * Name of the configured event producer
         */
        @NotBlank
        private String eventProducerName;

        /**
         * Source identifier for events, used to indicate the origin of a message.
         */
        @NotBlank
        private String source;

        /**
         * Event type string used for resource creation.
         */
        @NotBlank
        private String resourceCreatedType;

        /**
         * Event type string used for resource update.
         */
        @NotBlank
        private String resourceUpdatedType;

        /**
         * Event type string used for resource deletion.
         */
        @NotBlank
        private String resourceDeletedType;

        /**
         * Messaging Event type string used for resource event creation.
         */
        @NotBlank
        private String resourceCreatedEventType;

        /**
         * Messaging Event type string used for resource event update.
         */
        @NotBlank
        private String resourceUpdatedEventType;

        /**
         * Messaging Event type string used for resource event deletion.
         */
        @NotBlank
        private String resourceDeletedEventType;

        /**
         * Messaging Event type string used for resource event deletion.
         */
        @NotBlank
        private String resourceSubscriptionEventType;

    }

    /**
     * Configuration properties for diagnostics-related features.
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Diagnostics {
        /**
         * Controls whether the publish message diagnostic endpoint is enabled.
         */
        private boolean publishMessageEnabled;
    }
}

==> wp2-be-event-bs-server-1.2.0-sources.jar: com/finconsgroup/itserr/marketplace/event/bs/configuration/properties/EventBsConfigurationProperties.java <==
package com.finconsgroup.itserr.marketplace.event.bs.configuration.properties;

import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.validation.annotation.Validated;

/**
 * Configuration properties for the event bs service.
 * <p>
 * These properties are mapped from the {@code event.bs} prefix in the application configuration.
 */
@Data
@Validated
@ConfigurationProperties(prefix = "event.bs")
public class EventBsConfigurationProperties {

    /**
     * Base URL used by Swagger/OpenAPI documentation.
     * Example: {@code http://localhost:8080}
     */
    @NotBlank
    private String swaggerApiServerUrl;

    /**
     * imagesFolderName The folder name in the user's workspace to store image for event.
     */
    @NotBlank
    private String imagesFolderName;

    /**
     * Messaging-related configuration properties.
     */
    @NotNull
    @Valid
    private Messaging messaging;

    /**
     * Diagnostics-related configuration properties.
     */
    @NotNull
    @Valid
    private Diagnostics diagnostics;

    /**
     * Configuration for messaging
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Messaging {

        /**
         * Name of the configured producer
         */
        @NotBlank
        private String producerName;

        /**
         * Name of the configured event producer
         */
        @NotBlank
        private String eventProducerName;

        /**
         * Source identifier for events, used to indicate the origin of a message.
         */
        @NotBlank
        private String source;

        /**
         * Event type string used for resource creation.
         */
        @NotBlank
        private String resourceCreatedType;

        /**
         * Event type string used for resource update.
         */
        @NotBlank
        private String resourceUpdatedType;

        /**
         * Event type string used for resource deletion.
         */
        @NotBlank
        private String resourceDeletedType;

        /**
         * Messaging Event type string used for resource event creation.
         */
        @NotBlank
        private String resourceCreatedEventType;

        /**
         * Messaging Event type string used for resource event update.
         */
        @NotBlank
        private String resourceUpdatedEventType;

        /**
         * Messaging Event type string used for resource event deletion.
         */
        @NotBlank
        private String resourceDeletedEventType;

        /**
         * Messaging Event type string used for resource event subscribe.
         */
        @NotBlank
        private String resourceSubscriptionEventType;

        /**
         * Messaging Event type string used for resource event un-subscribe.
         */
        @NotBlank
        private String resourceUnSubscriptionEventType;

    }

    /**
     * Configuration properties for diagnostics-related features.
     */
    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Diagnostics {
        /**
         * Controls whether the publish message diagnostic endpoint is enabled.
         */
        private boolean publishMessageEnabled;
    }
}
